#!/bin/sh
# 
#
#
# File:     uninstall.sh
# Purpose:  Uninstall script for Xerox EPS LPR Filters
# Author:   Roxane Jager
# Created:  07/08/02
# License:  Copyright (C) 2002 Xerox Corporation.  All rights reserved.
#           Copyright protection claimed includes all forms and matters
#           of copyrightable material and information now allowed by
#           statutory or judicial law or hereinafter granted, including
#           without limitation, material generated from the software
#           programs which are displayed on the screen such as icons,
#           screen displays looks, etc.
#
#  Usage:  uninstall.sh    - Removes the XELF packages stored in
#                                 the current directory  
#          uninstall.sh rm_package_nobanner - Removes the XELF packages and
#                                             associated patches without start 
#                                             and end banners.
#          uninstall.sh <PKGDIR>            - Uninstalls the XELF packages
#                                             stored in the $PKGDIR directory.
#
# Modification History:
# ==========================================================================
# Date       Author       [SP]AR    Comments
# ~~~~~~~~~~ ~~~~~~~~~~~~ ~~~~~~~~  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# 07/15/2021  MK           Update remove_filters to call lprmain/deletefilter.sh
#	05/16/2006  RO				   DocuSP 50.60+ queue management support
############################################################################


#===========================
# COMMON DEFINES:
#===========================
PRODUCTNAME="Xerox Enhanced LPR/DSI Filters"     # Name of product used during display
XRXUSRDIR=/export/home/xrxusr           # xrxusr home directory
USER=`/usr/bin/whoami`                  # Login name of user executing this program
TMPDIR=/tmp                             # Temp files
TMPFILE1=$TMPDIR/tmp1
TMPFILE2=$TMPDIR/tmp2
THISAPPCAPTION="uninstall"              # Program's purpose: used during display
ALLARGS=$*                              # Get/store all command line arguments passed
BASE_DIR=/opt/XRXelf
TRUE="1"
FALSE="0"

######  Some more defines needed for the XELF-specific clean up
XELFBASEDIR=/opt/XRXelf
INTERFACE_DIR=/etc/lp/interfaces
PRINTERS=/etc/lp/printers

###### BSD ADAPTOR ########
BSD_ADAPTOR_DIR="/usr/lib/print/bsd-adaptor"
BSD_ADAPTOR_ORIG="$BSD_ADAPTOR_DIR/bsd_lpsched.so.original"
BSD_ADAPTOR_OTHER="$BSD_ADAPTOR_DIR/bsd_lpsched.so"

 
 
#===========================
# PACKAGING DEFINES:
#===========================
DEF_ADMINDIR="/export/home/xrxusr"
PRODPKG="XRXelf"
PACKAGENAMES="XRXelf" # Name of packages that will be installed or removed
OLDPACKAGENAMES=$PACKAGENAMES # Name of packages that will be installed or removed
TARZDIR="./"                           # Location where the <PACKAGE>.tar.Z file should exist (CD Install)
DEF_PKGDIR="/var/tmp"                  # PKGDIR used if not supplied at command line
 


#===========================
# ERROR HANDLING DEFINES:
#===========================
PROGRAMABORTVALUE=2                    # Return value for when an abort execution occurs


PATH=/opt/XRXelf:/optXRXelf/main:/usr/sbin:/usr/bin:/usr/ucb:/sbin:/packages; export PATH




###################################
# GENERAL MESSAGES
###################################
display_banner()
{
 if [ "$BANNERSEEN1" != "yes" ]; then
   clear
   echo "\nWelcome to the $PRODUCTNAME $THISAPPCAPTION program.\n"
   echo "This program will remove:"
   echo " - Any $PRODUCTNAME patches"
   echo " - All installation licenses"
   echo " - The $PRODUCTNAME packages (application and configuration files)"


   echo
   echo "\nDo you want to continue with the $THISAPPCAPTION? [y/n]: \c"
   getYNans || abortProcess
   
   # export BANNERSEEN1 so that we will not show this banner again
   # when we re-enter as root
   BANNERSEEN1=yes; export BANNERSEEN1
 fi
}
  

displayComplete()
{
  echo "\n>> The $THISAPPCAPTION is now complete."
  echo
}



####################################
# UNINSTALL XELF
####################################
Start_Uninstall()
{ 
 # # #
 # First get and save all arguments passed to program
 # Prepare uninstallation by:
 # - Showing banner. 
 # - Becoming root if not already.
 # Begin uninstallation by:
 # - Removing any previous patch instances (not installed at this time)
 # - Undoing Workspace menu options
 # - Removing the specified package
 #

  get_args $ALLARGS
  Uninstall_Init
  Uninstall_Package
  Uninstall_Cleanup
  displayComplete
}


Uninstall_Init()
{
  display_banner
  end_Xelfgui_processes
  become_root
  remove_filters 
  
}


###################################
# UTILITY FUNCTIONS
###################################
get_args()
{
  # $0 - Name of process (command name)
  # $1 - First arg: execution mode


  ARG1=${1:-"not_defined"}

  if [ $ARG1 != "not_defined" ];
  then
    # Uninstall PACKAGE 
    # Exit uninstaller
    #
    if [ $ARG1 = "rm_package_nobanner" ];
    then

       # Uninstall package without the startup banner
       Uninstall_Package

       # If called externally and package removal complete
       # exit uninstall process
       exitProcess
    else
       PKGDIR=$ARG1
    fi

  else
    PKGDIR=$DEF_PKGDIR 
  fi
 
}



pause()
{
  sleep 2
}


beep()
{
  echo ""
}



abortProcess()
{
  echo "\nAborting $THISAPPCAPTION...\n"
  exit $PROGRAMABORTVALUE
}

exitProcess()
{
  exit 0
}

restartPrompt()
{
  # Prompt to restart
  # If N, exit
  # Else if Y, init 6

  echo ">> Would you like to restart to allow changes to take effect? [y/n]\c"
  getYNans || exitProcess
  
  init 6
}



###################################
# UNINSTALLER INTERACTION
###################################
become_root()
{
# If we are not a root process
#  Display need to become root
#  while true
#    Attempt re-execution as root (prompts for root password)
#    If return value is an error but not $PROGRAMABORTVALUE,
#    then, password entry may be unsuccessful, 
#      prompt to try password entry again: y/n
#      If y, attempt re-execution again
#      IF n, abort process       
#    If return value is not an error,
#      we will re-execute this process as root and never re-enter here again
#      when new process ends, we will gracefully exit first process

 if [ "`/usr/bin/whoami`" != "root" ]; then

    echo "\nYou need to become root to continue $THISAPPCAPTION."
    
    # Allow multiple password re-entry if attempt failed
    
    while true
    do
        echo "Please enter your root password at the prompt below.\n"
	     
        # Attempt rexecution as root
        su root -c "exec ./$0"
        
        # Check for errors returned when attempting password entry
        # 0= successfull, 1 or any other= errors, $PROGRAMABORTVALUE= value used when aborting, 
        # If return value is an error but not $PROGRAMABORTVALUE,
        # then, password entry may be unsuccessful,
        # If return value is an error and we have not already started/finished execution,
        #    prompt to try password entry again
        # Else, exit gracefully
        
        if [ $? != "0"  -a  $? != "$PROGRAMABORTVALUE" ]
        then
           echo "Would you like to try again? [y/n] \c"
           getYNans || abortProcess
        else
           exitProcess
        fi
        echo
   done
 fi
 
 
}



############################
#
# Remove the interface files and 
# printers added for XELF
#
##############################

remove_filters()
{
  if [ -d "$XELFBASEDIR/configuration" ]; then

    echo "Removing XELF queues and printers."
    cd "$XELFBASEDIR/configuration"

    # Uninstall LPR filters
    for Files in `ls *.lpr.config`
    do
    if [ -f $Files ]; then
	    FILTER_INQ=`awk -F' = ' '{ if ($1 == "filter.input.queue") print $3 }' $Files`
	  
	    if [ ! -z "$FILTER_INQ" ]; then
            	
      echo "Removing XELF queue $FILTER_INQ"
    			
    			if [ -f /opt/XRXelf/configuration/$FILTER_INQ.lpr.config ] 
    				then
    					rm -f /opt/XRXelf/configuration/$FILTER_INQ.lpr.config
    				else
    					echo "Failed to remove file /opt/XRXelf/configuration/$FILTER_INQ.lpr.config"
    			fi
    			
    			# Call /opt/XRXelf/lprmain/deletfilter.sh to delete the printer
    			    
 			  $XELFBASEDIR/lprmain/deletefilter.sh -i $FILTER_INQ
    		sleep 5
	    fi
    fi
    done
    
  #Removed for S11  
  #  	/usr/lib/lpshut
  #	sleep 5
  # 	/usr/lib/lpsched
  # 	sleep 5
   	

    # Uninstall DSI filters
    for Files in `ls *.dsi.config`
    do
        if [ -f $Files ]; then
	    FILTER_PORT=`awk -F' = ' '{ if ($1 == "server.port") print $3 }' $Files`
	    if [ ! -z "$FILTER_PORT" ]; then
            	$XELFBASEDIR/dsimain/deletefilter.sh -p $FILTER_PORT
	    fi
        fi
    done

   # cd "$INTERFACE_DIR/backup"
   # for Files in `ls`
   # do
   #     if [ -f $Files ]; then 
   #         mv $Files ..
   #     fi
   # done
 fi
}

getYNans()
{
  while true
  do
	read response
	case $response in
	 [Yy]*) return 0 ;;
	 [Nn]*) return 1 ;;
	  *) echo "Please answer y or n: \c" ;;
        esac
    done
}



###################################
# END ALL Xelf PROCESSES
###################################
end_Xelfgui_processes()
{
  # Return if we already did this step!!
  if [ "$DIDSTEP_ENDXELF_PROCESSES" = "yes" ]; then
    return;
  fi

  if [ -d "$BASE_DIR/xelfgui"  ]; then
    echo "\n>> Ending all $PRODUCTNAME services..."
    endGui  
    DIDSTEP_ENDXELF_PROCESSES=yes; export DIDSTEP_ENDXELF_PROCESSES
  fi
}


endGui()
{
  if [ -f "$BASE_DIR/xelfgui/gui.sh"  ]; then
    $BASE_DIR/xelfgui/gui.sh stop >/dev/null 2>&1  
  fi
}



###################################
# PACKAGE REMOVAL
###################################
Remove_package()
{
  # Remove installed packages
  cd $PKGDIR
  for pkgnm in $OLDPACKAGENAMES
  do
     pkginfo | grep $pkgnm 1>/dev/null
     if [ "$?" -eq 0 ]; then
        echo   
        echo "Removing package $pkgnm"
        pkgrm -n -a $ADMINDIR/admin $pkgnm
     fi
  done
  
  pause  
}



Uninstall_Package()
{

  verify_admin_file 
  Remove_package
}

Uninstall_Cleanup()
{
  if [ -d "$BASE_DIR"  ]; then
    rm -rf "$BASE_DIR" >/dev/null 2>&1
  fi
}



verify_admin_file()
{
 # Proper execution of this program requires that 
 # "our" admin file exist.
 # Package removal can occur without "our" admin file, 
 # because pkgrm will use it's own default.
 #
 # If this occurs, removal is unpredictable.
 #
 # REQUIREMENTS:
 # admin file location = "./" or $ADMINDIR

 # First, verify that admin file exists at ADMINDIR

 
 if [ -f $ADMINDIR/admin ];
 then
    ADMINFILEFOUND=yes
    return
 fi

 if [ -f "./admin" ];
 then
   ADMINDIR="."
   ADMINFILEFOUND=yes
   return
 fi



ADMINDIR=$DEF_ADMINDIR

 if [ -f $ADMINDIR/admin ];
 then
   ADMINFILEFOUND=yes
   return
 fi


 # If we get here, the Admin file was not found
 ADMINFILEFOUND=no


}


###################################
# BEGIN EXECUTION HERE
###################################
Start_Uninstall $ALLARGS
